.. _data:

delu.data
=========

.. currentmodule:: delu.data

.. automodule:: delu.data

.. autosummary::
    :nosignatures:
    :toctree: api
    :template: class.rst

    Enumerate
    FnDataset
    IndexDataset

----

.. rubric:: Deprecated items

.. raw:: html

   <details>
   <summary>Show</summary>

.. autosummary::
    :nosignatures:
    :toctree: api

    make_index_dataloader

.. autosummary::
    :nosignatures:
    :toctree: api
    :template: class.rst

    IndexLoader

.. raw:: html

   </details>
